@@ -6,7 +6,7 @@ from threading import Thread
 import time
 import traceback
 from typing import Optional, Tuple, Union
-from urllib.parse import urlparse
+from urllib.parse import quote, urlparse
 
 from .utils import (
     _get_or_create_resource_archive,
@@ -19,7 +19,6 @@ from ..interfaces.resource import (
     Resource,
     ResourceState,
     ResourceUploader,
-    ResourceVisibility,
     SyncResourceUploader,
 )
 from ..utils import logger
@@ -185,7 +184,7 @@ def _create_new_algorithm(name: str) -> Algorithm:
     algo = Algorithm(
         name=name,
         description="SDK_QUICKSTART",
-        visibility=ResourceVisibility.PRIVATE,
+        public=False,
         filename=f"{name}.zip", # legacy
         is_zipfile=True, # legacy
         follows_anylearn_norm=False,
@@ -261,7 +260,7 @@ def _sync_algorithm_repo(
 def _auth_git_url(url):
     p = urlparse(url)
     root = p.netloc.split('@')[-1]
-    auth = f"{AnylearnConfig.username}:{AnylearnConfig.password}"
+    auth = f"{AnylearnConfig.username}:{quote(AnylearnConfig.password)}"
     return p._replace(netloc=f"{auth}@{root}").geturl()
 
 
